stdin

Function stdin 

pub async fn stdin(inbox: Receiver<Val>, back: Sender<Event>)
('host stdin): ('read) or ('read prompt), answering the text or 'eof. A prompt is ignored on a stream that is not a terminal, and a cast is dropped since there is nowhere to put the line.